Transforms
=========

This module contains various transformation classes and utilities for processing molecular data.

Core Transform Classes
--------------------

.. automodule:: atomworks.ml.transforms.base
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.af3_reference_molecule
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.atom_array
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.atom_frames
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.atomize
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.bonds
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.chirals
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.covalent_modifications
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.crop
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.encoding
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.featurize_unresolved_residues
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.filters
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.masks
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.sasa
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.symmetry
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.template
   :members:
   :undoc-members:
   :show-inheritance:

Utility Modules
-------------

.. automodule:: atomworks.ml.transforms._checks
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.center_random_augmentation
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.openbabel_utils
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.rdkit_utils
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: atomworks.ml.transforms.rf2aa_assumptions
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
---------

DNA Transforms
~~~~~~~~~~~~

.. automodule:: atomworks.ml.transforms.dna
   :members:
   :undoc-members:
   :show-inheritance:

Diffusion Transforms
~~~~~~~~~~~~~~~~~

.. automodule:: atomworks.ml.transforms.diffusion
   :members:
   :undoc-members:
   :show-inheritance:

ESM Transforms
~~~~~~~~~~~~

.. automodule:: atomworks.ml.transforms.esm
   :members:
   :undoc-members:
   :show-inheritance:

Feature Aggregation Transforms
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: atomworks.ml.transforms.feature_aggregation
   :members:
   :undoc-members:
   :show-inheritance:

MSA Transforms
~~~~~~~~~~~~

.. automodule:: atomworks.ml.transforms.msa
   :members:
   :undoc-members:
   :show-inheritance: 